# Contributing to PSP

Thank you for your interest in contributing to PSP! There are many ways to contribute
and we appreciate all of them.

The best way to get started is by reading the README and CODE\_OF\_CONDUCT files.

Also read the documentation of [Python](https://docs.python.org/3/) project, before write or add a piece of code.

Bug fixes, feature additions, tests, documentation and more can be contributed via issues and/or pull requests.
**All contributions are welcome**.

## Bug fixes, feature additions, etc.

Please send a pull request to the `main` branch.
Tests or documentation without bug fixes or feature additions are welcome too.
Feel free to ask questions via issues, discussions, or mail.

- Fork the PSP repository.
- Create a branch from `main`.
- Develop bug fixes, features, tests, etc.
- Create a pull request to pull the changes from your branch to the PSP `main`.

## Guidelines

- Separate code commits from reformatting commits.
- Follow [Rust Style Guide](https://doc.rust-lang.org/nightly/style-guide/).
- Include release notes as needed or appropriate with your bug fixes, feature additions.
- Do not add to the changelog for proposed changes, as that is updated after changes are merged.
